@@ -1,11 +1,13 @@
 import pandas as pd
 import pandas_datareader as pdr
+import matplotlib
 import matplotlib.pyplot as plt
 import seaborn as sns
-
 from scalecast.Forecaster import Forecaster
 
-df = pdr.get_data_fred('HOUSTNSA',start='1900-01-01',end='2021-05-01')
+models = ('knn','svr','lightgbm','mlp')
+level_models = ('arima','hwes','prophet','silverkite')
+df = pdr.get_data_fred('HOUSTNSA',start='1900-01-01',end='2021-06-01')
 f = Forecaster(y=df['HOUSTNSA'],current_dates=df.index) # to initialize, specify y and current_dates (must be arrays of the same length)
 
 f.set_test_length(12) # specify a test length for your models--it's a good idea to keep this the same for all forecasts
@@ -22,32 +24,29 @@ f.add_poly_terms('t',pwr=3) # by default, creates an order 2 regressor, n-order
 f.set_validation_length(6) # length, different than test_length, to tune the hyperparameters 
 
 # automatically tune and forecast with a series of models
-models = ('mlr','knn','svr','xgboost','gbt','elasticnet','mlp')
-level_models = ('arima','hwes','prophet')
-for m in models:
-	f.set_estimator(m)
-	f.tune() # by default, will pull the grid with the same name as the estimator (mlr will pull the mlr grid, etc.)
-	f.auto_forecast()
+f.tune_test_forecast(models,feature_importance=True,summary_stats=True)
 
 # combine models and run manually specified models of other varieties
 f.set_estimator('combo')
-f.manual_forecast(how='simple',models='top_3',determine_best_by='ValidationMetricValue',call_me='avg') # simple average of top_3 models based on performance in validation
-f.manual_forecast(how='weighted',models=models,determine_best_by='ValidationMetricValue',call_me='weighted') # weighted average of all models based on metric specified in determine_best_by (default is the validation metric)
+f.manual_forecast(how='simple',models=models,determine_best_by='ValidationMetricValue',call_me='avg_diff') # simple average of top_3 models based on performance in validation
+f.manual_forecast(how='weighted',models=models,determine_best_by='ValidationMetricValue',call_me='weighted_diff') # weighted average of all models based on metric specified in determine_best_by (default is the validation metric)
 
+# undifference results to bring back orginal series
 f.undiff()
-for m in level_models:
-	f.set_estimator(m)
-	f.tune()
-	f.auto_forecast()
+f.tune_test_forecast(level_models,feature_importance=True,summary_stats=True)
 
 # combine models and run manually specified models of other varieties
 f.set_estimator('combo')
 f.manual_forecast(how='simple',models=level_models,determine_best_by='ValidationMetricValue',call_me='avg_level') # simple average of top_3 models based on performance in validation
 f.manual_forecast(how='weighted',models=level_models,determine_best_by='ValidationMetricValue',call_me='weighted_level')
 
-f.plot(models='top_5',order_by='LevelTestSetMAPE',print_attr=['LevelTestSetRMSE','LevelTestSetR2','LevelTestSetMAPE','HyperParams','Xvars','models']) # will automatically plot levels for everything
-f.plot_test_set(models='top_5',order_by='LevelTestSetR2',include_train=60) # will automatically plot levels for everything
-f.plot_fitted(models=models + ('avg','weighted'),order_by='TestSetR2') # cannot plot fitted values of all models when levels were different during forecasting
-f.plot_fitted(models=level_models + ('avg_level','weighted_level'),order_by='TestSetR2')
+# plot results
+matplotlib.use('QT5Agg')
+f.plot(models='all',order_by='LevelTestSetMAPE',print_attr=['LevelTestSetRMSE','LevelTestSetR2','LevelTestSetMAPE','HyperParams','Xvars','models']) # will automatically plot levels for everything
+f.plot_test_set(models='all',order_by='LevelTestSetMAPE',include_train=60) # will automatically plot levels for everything
+f.plot_fitted(models=models,order_by='LevelTestSetMAPE') # cannot plot fitted values of all models when levels were different during forecasting
+f.plot_fitted(models=level_models,order_by='LevelTestSetMAPE')
 
-f.export(to_excel=True,determine_best_by='LevelTestSetMAPE',excel_name='housing_different_levels_results.xlsx') # export interesting model metrics and forecasts (both level and non-level)
\ No newline at end of file
+# export key results
+f.export(['model_summaries','lvl_fcsts'],to_excel=True,determine_best_by='LevelTestSetMAPE',excel_name='housing_different_levels_results.xlsx') # export interesting model metrics and forecasts (both level and non-level)
+f.all_feature_info_to_excel(excel_name='housing_different_levels_feature_info.xlsx')
\ No newline at end of file
